from .permission_map import PermissionMap

default_app_config = "bridgekeeper.apps.BridgekeeperConfig"

perms = PermissionMap()
